upload_land: Import and convert a shapefile to an object of class "lconnect"
Description
Import and convert a shapefile to an object of class "lconnect".
Some landscape and patch metrics which are the core of landscape connectivity
metrics are calculated. The shapefile must be projected, i.e., in planar
coordinates and the first field must contain the habitat categories.